/* (C) 2021 YiRing, Inc. */
package com.yiring.app.web;

import com.yiring.app.param.IdParam;
import com.yiring.app.param.PageParam;
import com.yiring.app.vo.PageVo;
import com.yiring.common.core.Result;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.Arrays;
import java.util.List;

@Slf4j
@Validated
@Api(tags = "Hello World")
@RestController("/")
public class HelloController {

    String text = "😎 Hello World";

    @GetMapping
    public Result<String> hello() {
        return Result.ok(text);
    }

    @GetMapping("id")
    public Result<Long> id(@Valid IdParam param) {
        return Result.ok(param.getId());
    }

    @GetMapping("page")
    public Result<PageVo<String>> page(@Valid PageParam pageParam) {
        log.info("PageParam: {}", pageParam);

        List<String> data = Arrays.asList(text.split(" "));
        PageVo<String> vo = PageVo.build(data, data.size());
        return Result.ok(vo);
    }
}
